#!/bin/bash

###################################################################################
# Based on the UCK - Ubuntu Customization Kit                                                  #
# Copyright (C) 2006-2007 UCK Team                                                #
#                                                                                 #
# This program is free software; you can redistribute it and/or                   #
# modify it under the terms of the GNU General Public License                     #
# as published by the Free Software Foundation; version 2                         #
# of the License.                                                                 #
#                                                                                 #
# This program is distributed in the hope that it will be useful,                 #
# but WITHOUT ANY WARRANTY; without even the implied warranty of                  #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                   #
# GNU General Public License for more details.                                    #
#                                                                                 #
# You should have received a copy of the GNU General Public License               #
# along with this program; if not, write to the Free Software                     #
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. #
###################################################################################

KEY_ID="$1" #D2681AF6
REMASTER_HOME="$2"

#############################
# general purpose functions #
#############################

usage()
{
	echo "Usage: $0 gpg-key-id [remaster-dir]"
}

failure()
{
	echo "$@"
	exit 1
}

#########################
# input parameter check #
#########################

if [ -z "$KEY_ID" ]; then
	usage
	exit 1
fi

if [ -z "$REMASTER_HOME" ]; then
	REMASTER_HOME=~/tmp
fi

########
# main #
########

# . libraries/remaster-live-cd.sh 2>/dev/null || . /usr/lib/uck/remaster-live-cd.sh 2>/dev/null || failure "libraries not found"

ISO_REMASTER_DIR="$REMASTER_HOME/SwissbuntuFiles"
REMASTER_ALT_TMP="$REMASTER_HOME/SwissbuntuFiles-tmp"

if [ ! -e "$ISO_REMASTER_DIR" ]; then
	failure "ISO remastering directory does not exists"
fi

############################
# creating pool structures #
############################

mkdir -p $ISO_REMASTER_DIR/dists/stable/extras/binary-i386 $ISO_REMASTER_DIR/pool/extras
mkdir -p $REMASTER_ALT_TMP/keyring
mkdir -p $REMASTER_ALT_TMP/indices

#####################################
# creating realease file for extras #
#####################################

cat $ISO_REMASTER_DIR/dists/stable/main/binary-i386/Release | sed 's/Component: main/Component: extras/' > $ISO_REMASTER_DIR/dists/stable/extras/binary-i386/Release

##############################
# detecting release codename #
##############################

cd $ISO_REMASTER_DIR/dists
RELEASE_CODENAME=`find stable -printf %l` # get the target of simlink stable

#######################
# downloading indices #
#######################

cd $REMASTER_ALT_TMP/indices
wget -c http://archive.ubuntu.com/ubuntu/indices/override.$RELEASE_CODENAME.{extra.main,main,main.debian-installer,restricted,restricted.debian-installer}

#############################
# processing ubuntu-keyring #
#############################

cd $REMASTER_ALT_TMP/keyring
# changed by fbianco
# apt-get source ubuntu-keyring
rm -f $REMASTER_ALT_TMP/keyring/ubuntu-keyring_2008.01.16.tar.gz
wget -c https://bugs.launchpad.net/ubuntu/hardy/+source/ubuntu-keyring/2008.01.16/+files/ubuntu-keyring_2008.01.16.tar.gz
tar xvf ubuntu-keyring_2008.01.16.tar.gz

cd $REMASTER_ALT_TMP/keyring/ubuntu-keyring-2008.01.16/keyrings/
gpg --import < ubuntu-archive-keyring.gpg
PACKAGE_SIGN=`gpg --list-keys $KEY_ID | grep uid | sed 's/uid *//'`
gpg --export FBB75451 437D05B5 $KEY_ID > ubuntu-archive-keyring.gpg
cd ..
dpkg-buildpackage -rfakeroot -m"fbianco" -k$KEY_ID # "$PACKAGE_SIGN"
cd ..
rm -f $ISO_REMASTER_DIR/pool/main/u/ubuntu-keyring/ubuntu-keyring*deb
cp ubuntu-keyring*deb $ISO_REMASTER_DIR/pool/main/u/ubuntu-keyring

#######################
# generating apt.conf #
#######################

cat $ISO_REMASTER_DIR/dists/$RELEASE_CODENAME/Release | egrep -v "^ " | egrep -v "^(Date|MD5Sum|SHA1|SHA256)" | sed 's/: / "/' | sed 's/^/APT::FTPArchive::Release::/' | sed 's/$/";/' > $REMASTER_ALT_TMP/apt.conf # FIXME PROBLEM ?!? seems not to work

######################################
# generating apt-ftparchive-deb.conf #
######################################

echo "Dir {
  ArchiveDir \"$ISO_REMASTER_DIR\";
};

TreeDefault {
  Directory \"pool/\";
};

BinDirectory \"pool/main\" {
  Packages \"dists/$RELEASE_CODENAME/main/binary-i386/Packages\";
  BinOverride \"$REMASTER_ALT_TMP/indices/override.$RELEASE_CODENAME.main\";
  ExtraOverride \"$REMASTER_ALT_TMP/indices/override.$RELEASE_CODENAME.extra.main\";
};

BinDirectory \"pool/restricted\" {
 Packages \"dists/$RELEASE_CODENAME/restricted/binary-i386/Packages\";
 BinOverride \"$REMASTER_ALT_TMP/indices/override.$RELEASE_CODENAME.restricted\";
};

Default {
  Packages {
    Extensions \".deb\";
    Compress \". gzip\";
  };
};

Contents {
  Compress \"gzip\";
};" > $REMASTER_ALT_TMP/apt-ftparchive-deb.conf

#######################################
# generating apt-ftparchive-udeb.conf #
#######################################

echo "Dir {
  ArchiveDir \"$ISO_REMASTER_DIR\";
};

TreeDefault {
  Directory \"pool/\";
};

BinDirectory \"pool/main\" {
  Packages \"dists/$RELEASE_CODENAME/main/debian-installer/binary-i386/Packages\";
  BinOverride \"$REMASTER_ALT_TMP/indices/override.$RELEASE_CODENAME.main.debian-installer\";
};

BinDirectory \"pool/restricted\" {
  Packages \"dists/$RELEASE_CODENAME/restricted/debian-installer/binary-i386/Packages\";
  BinOverride \"$REMASTER_ALT_TMP/indices/override.$RELEASE_CODENAME.restricted.debian-installer\";
};

Default {
  Packages {
    Extensions \".udeb\";
    Compress \". gzip\";
  };
};

Contents {
  Compress \"gzip\";
};" > $REMASTER_ALT_TMP/apt-ftparchive-udeb.conf

#########################################
# generating apt-ftparchive-extras.conf #
#########################################

echo "Dir {
  ArchiveDir \"$ISO_REMASTER_DIR\";
};

TreeDefault {
  Directory \"pool/\";
};

BinDirectory \"pool/extras\" {
  Packages \"dists/$RELEASE_CODENAME/extras/binary-i386/Packages\";
};

Default {
  Packages {
    Extensions \".deb\";
    Compress \". gzip\";
  };
};

Contents {
  Compress \"gzip\";
};" > $REMASTER_ALT_TMP/apt-ftparchive-extras.conf

##########################
# running apt-ftparchive #
##########################

echo $ISO_REMASTER_DIR
cd $ISO_REMASTER_DIR
apt-ftparchive -c $REMASTER_ALT_TMP/apt.conf generate $REMASTER_ALT_TMP/apt-ftparchive-deb.conf
apt-ftparchive -c $REMASTER_ALT_TMP/apt.conf generate $REMASTER_ALT_TMP/apt-ftparchive-udeb.conf
apt-ftparchive -c $REMASTER_ALT_TMP/apt.conf generate $REMASTER_ALT_TMP/apt-ftparchive-extras.conf
apt-ftparchive -c $REMASTER_ALT_TMP/apt.conf release dists/$RELEASE_CODENAME/ > dists/$RELEASE_CODENAME/Release

###################
# signing release #
###################

rm -f $ISO_REMASTER_DIR/dists/$RELEASE_CODENAME/Release.gpg
cp 
gpg --default-key "$KEY_ID" --output $ISO_REMASTER_DIR/dists/$RELEASE_CODENAME/Release.gpg -ba $ISO_REMASTER_DIR/dists/$RELEASE_CODENAME/Release
